@@ -25,6 +25,27 @@ def get_opts(prog_name="znp"):
         that belongs to pid 1234567.
         """,
     )
+    parser.add_argument(
+        "-e",
+        "--execute",
+        metavar="COMMAND",
+        action="store",
+        help="""
+        Execute the given command in the instance corresponding to the given
+        FILE
+        """,
+    )
+    parser.add_argument(
+        "-g",
+        "--page",
+        metavar="PAGE_NUMBER",
+        action="store",
+        type=int,
+        default=-1,
+        help="""
+        Used for executing commands for greater precision but not required.
+        """,
+    )
     parser.add_argument(
         "-n",
         "--next",
