@@ -1,6 +1,11 @@
 #!/usr/bin/env python3
 import re
-from .promptx import PromptX, PromptXCmdError, PromptXError, PromptXSelectError
+from promptx import (
+    PromptX,
+    PromptXCmdError,
+    PromptXError,
+    PromptXSelectError,
+)
 
 
 class InvalidCmdPrompt(Exception):
