@@ -3,7 +3,6 @@ import os
 import signal
 import socket
 import sys
-import time
 from threading import Thread
 
 
@@ -38,6 +37,7 @@ class SocketListener:
         # Loop until recieved the expected number of connections
         while self.recieved < self.expected:
             # Clean up data for new connection
+            page = None
             path = None
             pid = None
             # Listen for connection
@@ -48,6 +48,8 @@ class SocketListener:
                     # Get header, should be a pid padded with zeros
                     if not pid:
                         pid = connection.recv(7)
+                    if not page:
+                        page = connection.recv(24)
                     # Store temp_data
                     temp_path = connection.recv(1024)
                     if temp_path:
@@ -62,13 +64,12 @@ class SocketListener:
                         # Decode message
                         pid = pid.decode(encoding="utf-8")
                         pid = str(int(pid))
-                        path = path.decode(encoding="utf-8")
-                        # self.pids.append(header)
+                        page = page.decode(encoding="utf-8")
+                        if path is not None:
+                            path = path.decode(encoding="utf-8")
                         pids.append(pid)
-                        # self.pid_dict[header] = []
                         pid_dict[pid] = []
-                        # self.pid_dict[header].extend([path, f"{pid}: {path}"])
-                        pid_dict[pid].extend([path, f"{pid}: {path}"])
+                        pid_dict[pid].extend([pid, page, path])
                         break
             finally:
                 # Clean up the connection
@@ -86,7 +87,7 @@ class SocketListener:
                 raise
 
 
-def send_to_socket(pid, parent_pid, file_path, server_address):
+def send_to_socket(pid, parent_pid, file_path, server_address, page_number):
     """
     Send message to socket.
     The pid is used as the header.
@@ -107,8 +108,10 @@ def send_to_socket(pid, parent_pid, file_path, server_address):
     # Try sending data
     try:
         pid = bytes(str(pid).zfill(7), encoding="utf-8")
+        page = bytes(str(page_number).zfill(24), encoding="utf-8")
         file_path = bytes(str(file_path), encoding="utf-8")
         sock.sendall(pid)
+        sock.sendall(page)
         sock.sendall(file_path)
     finally:
         sock.close()
